BoxPlot

Struct BoxPlot 

pub struct BoxPlot<K, O> { /* private fields */ }

Implementations

Source

impl<K> BoxPlot<K, Vertical<K, f64>>

pub fn vertical_from_key_quartiles(key: K, quartiles: Quartiles) -> Self

Constructs a new vertical box plot based on a key and quartiles.

Source

impl<K> BoxPlot<K, Horizontal<K, f64>>

pub fn horizontal_from_key_quartiles(key: K, quartiles: Quartiles) -> Self

Constructs a new horizontal box plot based on a key and quartiles.

Source

impl<K, O> BoxPlot<K, O>

pub fn with_line_style<S: Into<ShapeStyle>>(&mut self, style: S) -> &mut Self

Sets the line style used by the box plot

pub fn with_box_style<S: Into<ShapeStyle>>(&mut self, style: S) -> &mut Self

Sets the box style used to fill the box plot

pub fn with_width(&mut self, width: f64) -> &mut Self

Sets the width of the box.

pub fn with_whisker_width(&mut self, width: f64) -> &mut Self

Sets the width of the whiskers.