pub struct Quartiles {
pub lower_whisker: f64,
pub lower_quartile: f64,
pub median: f64,
pub upper_quartile: f64,
pub upper_whisker: f64,
}Expand description
Stores the whisker positions, quartiles and median.
Fields
lower_whisker: f64lower_quartile: f64median: f64upper_quartile: f64upper_whisker: f64Implementations
Sourceimpl Quartiles
impl Quartiles
Sourcepub fn new(
lower_whisker: f64,
lower_quartile: f64,
median: f64,
upper_quartile: f64,
upper_whisker: f64,
) -> Self
pub fn new( lower_whisker: f64, lower_quartile: f64, median: f64, upper_quartile: f64, upper_whisker: f64, ) -> Self
Constructs a new Quartiles instance.
Sourcepub fn new_min_max(values: &[f64]) -> Self
pub fn new_min_max(values: &[f64]) -> Self
Constructs a new Quartiles instance where whiskers are calculated as the minimum and maximum value. Use Quartiles::new_min_max_from_sorted if the data is already sorted.
Sourcepub fn new_min_max_from_sorted(values: &[f64]) -> Self
pub fn new_min_max_from_sorted(values: &[f64]) -> Self
Constructs a new Quartiles instance where whiskers are calculated as the minimum and maximum value.
Sourcepub fn new_iqr(values: &[f64]) -> Self
pub fn new_iqr(values: &[f64]) -> Self
Constructs a new Quartiles instance where whiskers are calculated using interquartile range (https://en.wikipedia.org/wiki/Interquartile_range). Use Quartiles::new_iqr_from_sorted if the data is already sorted.
Sourcepub fn new_iqr_from_sorted(values: &[f64]) -> Self
pub fn new_iqr_from_sorted(values: &[f64]) -> Self
Constructs a new Quartiles instance from sorted data. where whiskers are calculated using interquartile range (https://en.wikipedia.org/wiki/Interquartile_range).