pub struct BoxPlot<K, O> { /* private fields */ }Implementations
Sourceimpl<K> BoxPlot<K, Vertical<K, f64>>
impl<K> BoxPlot<K, Vertical<K, f64>>
Sourcepub fn vertical_from_key_quartiles(key: K, quartiles: Quartiles) -> Self
pub fn vertical_from_key_quartiles(key: K, quartiles: Quartiles) -> Self
Constructs a new vertical box plot based on a key and quartiles.
Sourceimpl<K> BoxPlot<K, Horizontal<K, f64>>
impl<K> BoxPlot<K, Horizontal<K, f64>>
Sourcepub fn horizontal_from_key_quartiles(key: K, quartiles: Quartiles) -> Self
pub fn horizontal_from_key_quartiles(key: K, quartiles: Quartiles) -> Self
Constructs a new horizontal box plot based on a key and quartiles.
Sourceimpl<K, O> BoxPlot<K, O>
impl<K, O> BoxPlot<K, O>
Sourcepub fn with_line_style<S: Into<ShapeStyle>>(&mut self, style: S) -> &mut Self
pub fn with_line_style<S: Into<ShapeStyle>>(&mut self, style: S) -> &mut Self
Sets the line style used by the box plot
Sourcepub fn with_box_style<S: Into<ShapeStyle>>(&mut self, style: S) -> &mut Self
pub fn with_box_style<S: Into<ShapeStyle>>(&mut self, style: S) -> &mut Self
Sets the box style used to fill the box plot
Sourcepub fn with_width(&mut self, width: f64) -> &mut Self
pub fn with_width(&mut self, width: f64) -> &mut Self
Sets the width of the box.
Sourcepub fn with_whisker_width(&mut self, width: f64) -> &mut Self
pub fn with_whisker_width(&mut self, width: f64) -> &mut Self
Sets the width of the whiskers.